==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective.md <==
# AwsBackupRecoveryTimeObjective


```text
aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective
```

```text
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')
```



| Illustration | AwsBackupRecoveryTimeObjective | AwsBackupRecoveryTimeObjectiveCard | AwsBackupRecoveryTimeObjectiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective.png) | ![illustration for AwsBackupRecoveryTimeObjective](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective.Local.png) | ![illustration for AwsBackupRecoveryTimeObjectiveCard](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjectiveCard.Local.png) | ![illustration for AwsBackupRecoveryTimeObjectiveGroup](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjectiveGroup.Local.png) |




## AwsBackupRecoveryTimeObjective

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjective
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjective('AwsBackupRecoveryTimeObjective', 'Aws Backup Recovery Time Objective', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjective
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjective('AwsBackupRecoveryTimeObjective', 'Aws Backup Recovery Time Objective', 'an optional tech label')
@enduml
```

## AwsBackupRecoveryTimeObjectiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjectiveCard
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjectiveCard('AwsBackupRecoveryTimeObjectiveCard', 'Aws Backup Recovery Time Objective Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjectiveCard
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjectiveCard('AwsBackupRecoveryTimeObjectiveCard', 'Aws Backup Recovery Time Objective Card', 'an optional description')
@enduml
```

## AwsBackupRecoveryTimeObjectiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjectiveGroup
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjectiveGroup('AwsBackupRecoveryTimeObjectiveGroup', 'Aws Backup Recovery Time Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjectiveGroup
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjectiveGroup('AwsBackupRecoveryTimeObjectiveGroup', 'Aws Backup Recovery Time Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective.md <==
# AwsBackupRecoveryTimeObjective


```text
aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective
```

```text
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')
```



| Illustration | AwsBackupRecoveryTimeObjective | AwsBackupRecoveryTimeObjectiveCard | AwsBackupRecoveryTimeObjectiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective.png) | ![illustration for AwsBackupRecoveryTimeObjective](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective.Local.png) | ![illustration for AwsBackupRecoveryTimeObjectiveCard](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjectiveCard.Local.png) | ![illustration for AwsBackupRecoveryTimeObjectiveGroup](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjectiveGroup.Local.png) |




## AwsBackupRecoveryTimeObjective

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjective
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjective('AwsBackupRecoveryTimeObjective', 'Aws Backup Recovery Time Objective', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjective
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjective('AwsBackupRecoveryTimeObjective', 'Aws Backup Recovery Time Objective', 'an optional tech label')
@enduml
```

## AwsBackupRecoveryTimeObjectiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjectiveCard
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjectiveCard('AwsBackupRecoveryTimeObjectiveCard', 'Aws Backup Recovery Time Objective Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjectiveCard
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjectiveCard('AwsBackupRecoveryTimeObjectiveCard', 'Aws Backup Recovery Time Objective Card', 'an optional description')
@enduml
```

## AwsBackupRecoveryTimeObjectiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjectiveGroup
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjectiveGroup('AwsBackupRecoveryTimeObjectiveGroup', 'Aws Backup Recovery Time Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryTimeObjectiveGroup
include('aws-20210730/Resource/Storage/AwsBackupRecoveryTimeObjective')

' renders the element
AwsBackupRecoveryTimeObjectiveGroup('AwsBackupRecoveryTimeObjectiveGroup', 'Aws Backup Recovery Time Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
